SFPE Handbook of Fire Protection Engineering
============================================

Society of Fire Protection Engineers Handbook calculations.

.. automodule:: ofire.sfpe_handbook
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 14
----------

.. automodule:: ofire.sfpe_handbook.chapter_14
   :members:
   :undoc-members:
   :show-inheritance:

Alpert Correlations
~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_14.alpert
   :members:
   :undoc-members:
   :show-inheritance:

Heat Release Rate Correlations
""""""""""""""""""""""""""""""

.. automodule:: ofire.sfpe_handbook.chapter_14.alpert.heat_release
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 50 - Smoke Control
-------------------------

.. automodule:: ofire.sfpe_handbook.chapter_50
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.1 - Pressure Difference Due to Stack Effect
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This equation calculates the pressure difference due to :ref:`stack effect <stack-effect>`.

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_1
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.2 - Pressure Difference between a Fire Compartment and its Surroundings
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This equation calculates the pressure difference due to :ref:`stack effect <stack-effect>` between a fire compartment and its surroundings.

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_2
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.4 - Pressure Exerted by Wind on a Wall
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_4
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.6 - Upper Limit Pressure Difference for Piston Effect
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_6
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.7 - Effective Area for Elevator with Enclosed Lobbies
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_7
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.14 - Door Opening Force Resulting from Pressure Differences
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_14
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.15 - Height Limit for Pressurization Systems
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_15
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.16 - Flow Area Factor for Pressurization Systems
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_16
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.17 - Stairwell Temperature for Untreated Pressurization Air
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_17
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.18 - Fractional Effective Dose
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_18
   :members:
   :undoc-members:
   :show-inheritance:

Equation 50.19 - Visibility Through Uniform Smoke
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_19
   :members:
   :undoc-members:
   :show-inheritance:
Equation 50.20 - Visibility Through Smoke (Percent Obscuration)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_50.equation_50_20
   :members:
   :undoc-members:
   :show-inheritance: